package de.laliluna.example.pages;

import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.Persist;
import org.apache.tapestry5.annotations.InjectPage;
import org.apache.tapestry5.Link;
import org.apache.tapestry5.StreamResponse;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.Response;
import org.apache.tapestry5.internal.services.LinkImpl;

import java.util.List;
import java.net.URL;
import java.net.MalformedURLException;
import java.io.InputStream;
import java.io.IOException;
import java.io.FileInputStream;
import java.io.File;

/**
 * A number of navigation examples. The event methods return different responses.
 * Author: Sebastian Hennebrueder, http://www.laliluna.de
 * Date: 06.08.2009
 */
public class Navigation {

	@Property
	@Persist
	private String message;

	@Property
	private int current;

	@InjectPage
	private NavigationTarget target;

	/**
	 *
	 * @return null to stay on the same page
	 */
	Object onActionFromNullresponse() {
		message = "Null response action";
		return null;
	}

	/**
	 *
	 * @return a page name to navigate to
	 */
	Object onActionFromStringreponse() {
		return "NavigationTarget";
	}

	/**
	 *
	 * @return a page class to navigate to
	 */
	Object onActionFromClassresponse() {
		return NavigationTarget.class;
	}

	/**
	 * Makes use of the page injected by Tapestry and initialize the page. The name of the method <i>initialize</i>
	 * is a convention.
	 * @return
	 */
	Object onActionFromInstanceresponse() {
		return target.initialize("Instance response");
	}

	/**
	 *
	 * @return an external URL
	 */
	Object onActionFromUrlresponse() throws MalformedURLException {
			URL url = new URL("http", "www.laliluna.de", "");
			return url;
	}

	/**
	 *
	 * @param passedValue - a value passed from the link
	 * @return null to stay on the same page
	 */
	Object onActionFromLink(int passedValue) {
		message = "Value is " + passedValue;
		return null;
	}

	/**
	 *
	 * @return an inputStream rendering a PDF
	 */
	Object onActionFromPdf() {
		return new StreamResponse() {

			public String getContentType() {
				return "application/pdf";
			}

			public InputStream getStream() throws IOException {
				return getClass().getResourceAsStream("sample.pdf");
			}

			public void prepareResponse(Response response) {
				response.setHeader("Content-disposition", "Attachment; filename=sample.pdf");
			}
		};
	}
}
