package de.laliluna.example.util;

import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Application state object. Stores a class holding dialog information by a dialogId.
 * Every dialog need to get a dialogId assigned.
 *
 * @author Sebastian Hennebrueder
 */

public class DialogState<T> {
	private ConcurrentMap<Integer, T> dialogs = new ConcurrentHashMap<Integer,T>();

	private static AtomicInteger dialogId = new AtomicInteger();
	// used to prevent an int overflow, we are going to restart the id in that case
	private static final int overFlowLimit = Integer.MAX_VALUE - 1;

	public T getBean(Integer dialogId) {
		T t = dialogs.get(dialogId);
		if (t == null)
			throw new IllegalStateException("There is no data for the given dialog id: " + dialogId);
		return t;
	}

	public void setBean(Integer dialogId, T bean) {
		dialogs.put(dialogId, bean);
	}

	public int startDialog(T bean) {
		int id;
		synchronized (dialogId) {
			id = dialogId.incrementAndGet();
			if (id >= overFlowLimit) {
				dialogId.set(0);
			}
		}
		setBean(id, bean);
		return id;
	}

	public void endDialog(Integer dialogId) {
		dialogs.remove(dialogId);
	}

	public boolean empty() {
		return dialogs.size() == 0;
	}
}
