package de.laliluna.example.util;

import org.apache.tapestry5.services.RequestFilter;
import org.apache.tapestry5.services.Request;
import org.apache.tapestry5.services.Response;
import org.apache.tapestry5.services.RequestHandler;

import java.io.IOException;

import de.laliluna.example.mixins.DoubleSubmit;
import de.laliluna.example.services.FormSubmitIdService;

/**
 * Author: Sebastian Hennebrueder, http://www.laliluna.de
 * Date: 10.08.2009
 */
public class DoubleSubmitFilter implements RequestFilter {
	private FormSubmitIdService formSubmitIdService;

	public DoubleSubmitFilter(FormSubmitIdService formSubmitIdService) {
		this.formSubmitIdService = formSubmitIdService;
	}

	/**
	 * Returns true if the request has been handled, false otherwise.
	 */
	public boolean service(Request request, Response response, RequestHandler handler) throws IOException {
		String parameter = request.getParameter(DoubleSubmit.SUBMIT_ID);
		if (parameter != null) {
			try {
				int id = Integer.parseInt(parameter);
				if (!formSubmitIdService.checkAndRemove(id))
					throw new IllegalStateException(String.format("Form id %d is not valid.", id));
			} catch (NumberFormatException e) {
				throw new IllegalStateException(String.format("Form id %s is not valid.", parameter));
			}
		}
		return handler.service(request, response);
	}
}
