package de.laliluna.example.util;

import org.apache.tapestry5.internal.translator.AbstractTranslator;
import org.apache.tapestry5.Field;
import org.apache.tapestry5.ValidationException;
import org.apache.tapestry5.MarkupWriter;
import org.apache.tapestry5.services.FormSupport;
import de.laliluna.example.model.Phone;

/**
 * Transforms a phone number to an output like +49 / 5555 / 4444 and back from a String to a phone number.
 * 
 * Author: Sebastian Hennebrueder, http://www.laliluna.de
 * Date: 06.08.2009
 */
public class PhoneTranslator extends AbstractTranslator<Phone>{
	public PhoneTranslator() {
		super("phone", Phone.class, "phone");
	}

	/**
	 * Converts a server-side value to a client-side string. This allows for formatting of the value in a way
	 * appropriate to the end user. The output client value should be parsable by {@link #parseClient(org.apache.tapestry5.Field , String,
	 * String)}.
	 *
	 * @param value the server side value (which will not be null)
	 * @return client-side value to present to the user
	 */
	public String toClient(Phone value) {
		return String.format("%s/%s/%s", value.getCountryCode(), value.getAreaPrefix(), value.getCode());
	}

	/**
	 * Converts a submitted request value into an appropriate server side value.
	 *
	 * @param field			 for which a value is being parsed
	 * @param clientValue to convert to a server value; this will not be null, but may be blank
	 * @param message		 formatted validation message, either from validation messages, or from an override
	 * @return equivalent server-side value (possibly null)
	 * @throws org.apache.tapestry5.ValidationException
	 *          if the value can not be parsed
	 */
	public Phone parseClient(Field field, String clientValue, String message) throws ValidationException {
		String[] strings = clientValue.split("/");
		if(strings.length != 3)
			throw new ValidationException(message);
		return new Phone(strings[0], strings[1], strings[2]);
	}

	/**
	 * Hook used by components to allow the validator to contribute additional attributes or (more often) client-side
	 * JavaScript (via the {@link org.apache.tapestry5.services.FormSupport#addValidation(org.apache.tapestry5.Field , String, String,
	 * Object)}).
	 *
	 * @param field			 the field which is currently being rendered
	 * @param message		 formatted validation message, either from validation messages, or from an override
	 * @param writer			markup writer, allowing additional attributes to be written into the active element
	 * @param formSupport used to add JavaScript
	 */
	public void render(Field field, String message, MarkupWriter writer, FormSupport formSupport) {

	}
}
