package de.laliluna.example.util;

import org.apache.tapestry5.ioc.ObjectProvider;
import org.apache.tapestry5.ioc.AnnotationProvider;
import org.apache.tapestry5.ioc.ObjectLocator;
import org.apache.tapestry5.ioc.services.RegistryShutdownHub;
import org.apache.tapestry5.ioc.services.RegistryShutdownListener;
import org.picocontainer.MutablePicoContainer;
import org.picocontainer.DefaultPicoContainer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import de.laliluna.example.services.SamplePicoServiceImpl;

/**
 * Author: Sebastian Hennebrueder, http://www.laliluna.de
 * Date: 10.08.2009
 */
public class PicoObjectProvider implements ObjectProvider, RegistryShutdownListener {
	private static MutablePicoContainer container = new DefaultPicoContainer();
	private final Logger logger = LoggerFactory.getLogger(PicoObjectProvider.class);

	public PicoObjectProvider() {
	}

	public void build(RegistryShutdownHub shutdownHub){
		container.addComponent(SamplePicoServiceImpl.class);
		container.start();
		shutdownHub.addRegistryShutdownListener(this);
	}

	public <T> T provide(Class<T> objectType, AnnotationProvider annotationProvider, ObjectLocator locator) {
		T object = container.getComponent(objectType);
		if (object != null)
			logger.debug("Pico created object {}", objectType);
		return object;
	}

	public void registryDidShutdown() {
		logger.debug("Shutting down Pico container");
		container.stop();
	}
}
